==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/mode/type/standalone/core/src/main/java/org/apache/shardingsphere/mode/manager/standalone/workerid/StandaloneWorkerIdGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.mode.manager.standalone.workerid;

import org.apache.shardingsphere.infra.exception.core.ShardingSpherePreconditions;
import org.apache.shardingsphere.infra.instance.workerid.WorkerIdAssignedException;
import org.apache.shardingsphere.infra.instance.workerid.WorkerIdGenerator;

import java.util.Properties;

/**
 * Worker ID generator for standalone mode.
 */
public final class StandaloneWorkerIdGenerator implements WorkerIdGenerator {
    
    private static final int DEFAULT_WORKER_ID = 0;
    
    @Override
    public int generate(final Properties props) {
        if (!props.containsKey(WORKER_ID_KEY)) {
            return DEFAULT_WORKER_ID;
        }
        int result = Integer.parseInt(props.get(WORKER_ID_KEY).toString());
        ShardingSpherePreconditions.checkState(result >= 0 && result <= MAX_WORKER_ID, WorkerIdAssignedException::new);
        return result;
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/mode/type/standalone/core/src/main/java/org/apache/shardingsphere/mode/manager/standalone/workerid/StandaloneWorkerIdGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.mode.manager.standalone.workerid;

import org.apache.shardingsphere.infra.exception.ShardingSpherePreconditions;
import org.apache.shardingsphere.infra.instance.workerid.WorkerIdAssignedException;
import org.apache.shardingsphere.infra.instance.workerid.WorkerIdGenerator;

import java.util.Properties;

/**
 * Worker ID generator for standalone mode.
 */
public final class StandaloneWorkerIdGenerator implements WorkerIdGenerator {
    
    private static final int DEFAULT_WORKER_ID = 0;
    
    @Override
    public int generate(final Properties props) {
        if (!props.containsKey(WORKER_ID_KEY)) {
            return DEFAULT_WORKER_ID;
        }
        int result = Integer.parseInt(props.get(WORKER_ID_KEY).toString());
        ShardingSpherePreconditions.checkState(result >= 0 && result <= MAX_WORKER_ID, WorkerIdAssignedException::new);
        return result;
    }
}
